@@ -766,10 +766,12 @@ sub latex {
     [% END %]
     \strut
   \end{center}
-\cleardoublepage
 [% ELSE %]
 \maketitle
 [% END %]
+[% UNLESS doc.header_as_latex.nocoverpage || options.nocoverpage %]
+\cleardoublepage
+[% END %]
 
 [% UNLESS options.notoc %]
 [% IF doc.wants_toc %]
@@ -832,8 +834,6 @@ sub latex {
 \textbf{[% options.site %]}
 [% END %]
 
-% Here an URL maybe?
-
 \end{center}
 
 \end{document}
